==> pt-br-2.1.7.zip: pt-br/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ----------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2010 Olivier Meunier and contributors
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK ------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Ir ao conteúdo';
$GLOBALS['__l10n']['To menu'] = 'Ir à ementa';
$GLOBALS['__l10n']['To search'] = 'Ir à pesquisa';
$GLOBALS['__l10n']['By'] = 'Por';
$GLOBALS['__l10n']['by'] = 'por';
$GLOBALS['__l10n']['on'] = 'o dia';
$GLOBALS['__l10n']['On'] = 'O dia';
$GLOBALS['__l10n']['Continue reading'] = 'Continue a leitura';
$GLOBALS['__l10n']['no comment'] = 'nenhum comentário';
$GLOBALS['__l10n']['one comment'] = 'um comentário';
$GLOBALS['__l10n']['%d comments'] = '%d comentários';
$GLOBALS['__l10n']['no trackback'] = 'nenhum trackback';
$GLOBALS['__l10n']['one trackback'] = 'um trackback';
$GLOBALS['__l10n']['%d trackbacks'] = '%d trackbacks';
$GLOBALS['__l10n']['no attachment'] = 'nenhum anexo';
$GLOBALS['__l10n']['one attachment'] = 'um anexo';
$GLOBALS['__l10n']['%d attachments'] = '%d anexos';
$GLOBALS['__l10n']['previous entries'] = 'posts anteriores';
$GLOBALS['__l10n']['page'] = 'página';
$GLOBALS['__l10n']['of'] = 'de';
$GLOBALS['__l10n']['next entries'] = 'posts seguintes';
$GLOBALS['__l10n']['Search'] = 'Pesquisa';
$GLOBALS['__l10n']['Home'] = 'Página principal';
$GLOBALS['__l10n']['All keywords'] = 'Todas as palavras chaves';
$GLOBALS['__l10n']['Best of me'] = 'O meu melhor';
$GLOBALS['__l10n']['Languages'] = 'Idiomas';
$GLOBALS['__l10n']['Categories'] = 'Categorias';
$GLOBALS['__l10n']['Archives'] = 'Arquivos';
$GLOBALS['__l10n']['Links'] = 'Links';
$GLOBALS['__l10n']['Subscribe'] = 'Assinar';
$GLOBALS['__l10n']['Entries feed'] = 'Feed dos posts';
$GLOBALS['__l10n']['This blog\'s entries RSS feed'] = 'Feed RSS dos posts deste blog';
$GLOBALS['__l10n']['Comments feed'] = 'Feed dos comentários';
$GLOBALS['__l10n']['This blog\'s comments RSS feed'] = 'Feed RSS dos comentários deste blog';
$GLOBALS['__l10n']['This category\'s entries RSS feed'] = 'Feed RSS dos posts desta categoria';
$GLOBALS['__l10n']['This category\'s comments RSS feed'] = 'Feed RSS dos comentários desta categoria';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Feed dos comentários deste post';
$GLOBALS['__l10n']['This post\'s comments RSS feed'] = 'Feed RSS dos comentários deste post';
$GLOBALS['__l10n']['Attachments'] = 'Anexos';
$GLOBALS['__l10n']['Permalink'] = 'Link permanente';
$GLOBALS['__l10n']['Comments'] = 'Comentários';
$GLOBALS['__l10n']['Your comment'] = 'Seu comentário';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Seu comentário foi publicado.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Seu comentário foi registrado e será publicado depois da aprobação.';
$GLOBALS['__l10n']['Add a comment'] = 'Acrescentar um comentário';
$GLOBALS['__l10n']['Name or nickname'] = 'Nome ou apelido';
$GLOBALS['__l10n']['Email address'] = 'Endereço de email';
$GLOBALS['__l10n']['Website'] = 'Saite web';
$GLOBALS['__l10n']['optional'] = 'opcional';
$GLOBALS['__l10n']['Comment'] = 'Comentário';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'O código HTML é exibido como texto e os endereços web são automaticamente transformados.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Se lembrar de mim neste blog';
$GLOBALS['__l10n']['preview'] = 'pré-visualizar';
$GLOBALS['__l10n']['send'] = 'enviar';
$GLOBALS['__l10n']['They posted on the same topic'] = 'A discussão continua em outros locais';
$GLOBALS['__l10n']['Trackback URL'] = 'URL de trackback';
$GLOBALS['__l10n']['You must provide an author name'] = 'Você tem de indicar um nome';
$GLOBALS['__l10n']['You must provide a comment'] = 'Você tem de escrever um comentário';
$GLOBALS['__l10n']['Email address is not valid'] = 'Endereço de email incorrecto';
$GLOBALS['__l10n']['Document not found'] = 'Nenhum documento encontrado';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'O documento que você procura não existe.';
$GLOBALS['__l10n']['Powered by'] = 'Powered by';
$GLOBALS['__l10n']['Subscribe to'] = 'Assinar';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'O que é um feed RSS?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Um feed RSS recolha as informações de actualização de um saite. Fornece o conteúdo dos posts ou os comentários ou um extracto destes, assim que links para as versões completas e algumas outras informações. Este feed tem por vocação de ser lido por um <a href="http://pt.wikipedia.org/wiki/Agregador">agregador</a> RSS.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Copiar simplesmente o endereço seguinte no seu agregador:';
$GLOBALS['__l10n']['Password needed'] = 'Senha necessária';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Você tem de indicar uma senha por acessar a essa parte.';
$GLOBALS['__l10n']['Password:'] = 'Senha:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Você tem de indicar um endereço de email válido.';
$GLOBALS['__l10n']['Read'] = 'Ler';
?>

==> pt-br-2.2.3.zip: pt-br/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2010 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Ir ao conteúdo';
$GLOBALS['__l10n']['To menu'] = 'Ir à ementa';
$GLOBALS['__l10n']['To search'] = 'Ir à pesquisa';
$GLOBALS['__l10n']['By'] = 'Por';
$GLOBALS['__l10n']['by'] = 'por';
$GLOBALS['__l10n']['on'] = 'o dia';
$GLOBALS['__l10n']['On'] = 'O dia';
$GLOBALS['__l10n']['Continue reading'] = 'Continue a leitura';
$GLOBALS['__l10n']['no comment'] = 'nenhum comentário';
$GLOBALS['__l10n']['one comment'] = 'um comentário';
$GLOBALS['__l10n']['%d comments'] = '%d comentários';
$GLOBALS['__l10n']['no trackback'] = 'nenhum trackback';
$GLOBALS['__l10n']['one trackback'] = 'um trackback';
$GLOBALS['__l10n']['%d trackbacks'] = '%d trackbacks';
$GLOBALS['__l10n']['no attachment'] = 'nenhum anexo';
$GLOBALS['__l10n']['one attachment'] = 'um anexo';
$GLOBALS['__l10n']['%d attachments'] = '%d anexos';
$GLOBALS['__l10n']['previous entries'] = 'posts anteriores';
$GLOBALS['__l10n']['page'] = 'página';
$GLOBALS['__l10n']['of'] = 'de';
$GLOBALS['__l10n']['next entries'] = 'posts seguintes';
$GLOBALS['__l10n']['Search'] = 'Pesquisa';
$GLOBALS['__l10n']['Home'] = 'Página principal';
$GLOBALS['__l10n']['All keywords'] = 'Todas as palavras chaves';
$GLOBALS['__l10n']['Best of me'] = 'O meu melhor';
$GLOBALS['__l10n']['Languages'] = 'Idiomas';
$GLOBALS['__l10n']['Categories'] = 'Categorias';
$GLOBALS['__l10n']['Subcategories'] = 'Categorias';
$GLOBALS['__l10n']['Archives'] = 'Arquivos';
$GLOBALS['__l10n']['Links'] = 'Links';
$GLOBALS['__l10n']['Subscribe'] = 'Assinar';
$GLOBALS['__l10n']['Entries feed'] = 'Feed dos posts';
$GLOBALS['__l10n']['Comments feed'] = 'Feed dos comentários';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Feed RSS dos comentários deste blog';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Feed RSS dos posts desta categoria';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Feed RSS dos comentários desta categoria';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Feed dos comentários deste post';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Feed dos comentários deste post';
$GLOBALS['__l10n']['Attachments'] = 'Anexos';
$GLOBALS['__l10n']['Permalink'] = 'Link permanente';
$GLOBALS['__l10n']['Comments'] = 'Comentários';
$GLOBALS['__l10n']['Your comment'] = 'Seu comentário';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Seu comentário foi publicado.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Seu comentário foi registrado e será publicado depois da aprobação.';
$GLOBALS['__l10n']['Add a comment'] = 'Acrescentar um comentário';
$GLOBALS['__l10n']['Name or nickname'] = 'Nome ou apelido';
$GLOBALS['__l10n']['Email address'] = 'Endereço de email';
$GLOBALS['__l10n']['Website'] = 'Saite web';
$GLOBALS['__l10n']['optional'] = 'opcional';
$GLOBALS['__l10n']['Comment'] = 'Comentário';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'O código HTML é exibido como texto e os endereços web são automaticamente transformados.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Se lembrar de mim neste blog';
$GLOBALS['__l10n']['preview'] = 'pré-visualizar';
$GLOBALS['__l10n']['send'] = 'enviar';
$GLOBALS['__l10n']['They posted on the same topic'] = 'A discussão continua em outros locais';
$GLOBALS['__l10n']['Trackback URL'] = 'URL de trackback';
$GLOBALS['__l10n']['You must provide an author name'] = 'Você tem de indicar um nome';
$GLOBALS['__l10n']['You must provide a comment'] = 'Você tem de escrever um comentário';
$GLOBALS['__l10n']['Email address is not valid'] = 'Endereço de email incorrecto';
$GLOBALS['__l10n']['Document not found'] = 'Nenhum documento encontrado';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'O documento que você procura não existe.';
$GLOBALS['__l10n']['Powered by %s'] = 'Powered by';
$GLOBALS['__l10n']['Subscribe to'] = 'Assinar';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'O que é um feed RSS?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Um feed RSS recolha as informações de actualização de um saite. Fornece o conteúdo dos posts ou os comentários ou um extracto destes, assim que links para as versões completas e algumas outras informações. Este feed tem por vocação de ser lido por um <a href="http://pt.wikipedia.org/wiki/Agregador">agregador</a> RSS.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Copiar simplesmente o endereço seguinte no seu agregador:';
$GLOBALS['__l10n']['Password needed'] = 'Senha necessária';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Você tem de indicar uma senha por acessar a essa parte.';
$GLOBALS['__l10n']['Password:'] = 'Senha:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Você tem de indicar um endereço de email válido.';
$GLOBALS['__l10n']['Read'] = 'Ler';
?>
